@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- * Copyright © 2016 James Hunt <jamesodhunt@ubuntu.com>.
+ * Copyright © 2016 James Hunt <jamesodhunt@gmail.com>.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,23 @@
 
 #define ROOT_PATH                    "/proc/self/root"
 
+/* Maximum length of a process name as shown by ps(1),
+ * /proc/$pid/comm, etc. Requires since there appears to be
+ * no standard userspace define for the TASK_COMM_LEN
+ * kernel define.
+ *
+ * See:
+ *
+ * - PR_SET_NAME in prctl(2).
+ * - pthread_setname_np(3).
+ */
+#define _PROCENV_TASK_COMM_LEN          16
+
+/* The usable amount of space for a process name
+ * (1 byte required for terminating '\0')
+ */
+#define PROCENV_TASK_COMM_NAME_LEN     (_PROCENV_TASK_COMM_LEN-1)
+
 #if defined (HAVE_NUMA_H)
 
 #include <numa.h>
@@ -90,9 +107,11 @@
 	int effective; \
 	int inheritable; \
 	int permitted; \
+	int ambient; \
 	\
 	bound = cap_get_bound (cap); \
 	\
+	ambient = get_ambient_capability (cap); \
 	effective = get_capability_by_flag_type (caps, CAP_EFFECTIVE, cap); \
 	inheritable = get_capability_by_flag_type (caps, CAP_INHERITABLE, cap); \
 	permitted = get_capability_by_flag_type (caps, CAP_PERMITTED, cap); \
@@ -112,6 +131,13 @@
 			? YES_STR \
 			: NO_STR); \
 	\
+	entry ("ambient", "%s", \
+			ambient < 0 \
+			? NOT_DEFINED_STR \
+			: permitted == CAP_SET \
+			? YES_STR \
+			: NO_STR); \
+	\
 	entry ("effective", "%s", \
 			effective < 0 \
 			? NOT_DEFINED_STR \
@@ -156,7 +182,7 @@ static int cap_get_bound (cap_value_t cap)
 /* semctl(2) states that POSIX.1-2001 requires the caller define this! */
 union semun {
 	int val;
-	struct semid_ds *buf;     
+	struct semid_ds *buf;
 	unsigned short int *array;
 	struct seminfo *__buf;
 };
@@ -166,9 +192,9 @@ static bool linux_kernel_version (int major, int minor, int revision);
 #if defined (HAVE_SYS_CAPABILITY_H)
 static int get_capability_by_flag_type (cap_t cap_p, cap_flag_t type, cap_value_t cap)
     __attribute__((unused));
+static int get_ambient_capability(cap_value_t cap)
+    __attribute__((unused));
 
-int get_capability_by_flag_type (cap_t cap_p, cap_flag_t type, cap_value_t cap);
 #endif /* HAVE_SYS_CAPABILITY_H */
 
-
 #endif /* _PROCENV_PLATFORM_LINUX_H */
