@@ -2234,7 +2234,7 @@ get_net_family_name (sa_family_t family)
 		break;
 #endif
 
-#if defined (PROCENV_PLATFORM_BSD)
+#if defined (PROCENV_PLATFORM_BSD) || defined (PROCENV_PLATFORM_DARWIN)
 	case AF_LINK:
 		return "AF_LINK";
 		break;
@@ -2846,46 +2846,6 @@ get_arch (void)
 	return UNKNOWN_STR;
 }
 
-#if ! defined (PROCENV_PLATFORM_ANDROID) && ! defined (PROCENV_PLATFORM_DARWIN)
-static int
-libs_callback (struct dl_phdr_info *info, size_t size, void *data)
-{
-	const char *name;
-	const char *path;
-
-	assert (info);
-
-	if (! info->dlpi_name || ! *info->dlpi_name)
-		return 0;
-
-	path = info->dlpi_name;
-	assert (path);
-
-	name = strrchr (path, '/');
-
-	if (name) {
-		/* Jump over slash */
-		name++;
-	} else {
-		/* BSD libraries don't show the path */
-		name = path;
-	}
-
-	object_open (false);
-
-	section_open (name);
-
-	entry ("path", "%s", path);
-	entry ("address", "%p", (void *)info->dlpi_addr);
-
-	section_close ();
-
-	object_close (false);
-
-	return 0;
-}
-#endif
-
 void
 show_libs (void)
 {
@@ -2893,9 +2853,8 @@ show_libs (void)
 
 	container_open ("libraries");
 
-#if ! defined (PROCENV_PLATFORM_ANDROID) && ! defined (PROCENV_PLATFORM_DARWIN)
-	dl_iterate_phdr (libs_callback, NULL);
-#endif
+	if (ops->show_libs)
+		ops->show_libs();
 
 	container_close ();
 }
